FileStore

Struct FileStore 

pub struct FileStore { /* private fields */ }
An implementation of Loader and Saver that reads and writes a configuration file.

Implementations

Source

impl FileStore

pub fn new(path: impl AsRef<Path>) -> Self

Create a new FileStore with the given path.

This FileStore will read and write to the file at the given path. Config data will be serialized and deserialized using the file extension. By default, this supports only .json files.